@@ -13,7 +13,8 @@ has record_methods => (
 );
 
 around 'local_dispatch' => sub {
-    my( $orig, $self, $id, $method, @args ) = @_;
+    my( $orig, $self ) = @_;
+    my( $id, $method, @args ) = @{ $self->path };
     $method ||= 'view';
     if( $id && $id =~ /^\d+$/ && $self->record_methods->{ $method } ){
         my $rs = $self->app->schema->resultset( 'Dvd' );
@@ -26,7 +27,7 @@ around 'local_dispatch' => sub {
         }
         return $self->$method( $record, @args );
     }
-    return $self->$orig( $id, $method, @args );
+    return $self->$orig();
 };
 
 sub index_action {
