@@ -3,13 +3,14 @@ use warnings;
 
 package WebNano::Controller;
 BEGIN {
-  $WebNano::Controller::VERSION = '0.006';
+  $WebNano::Controller::VERSION = '0.007';
 }
 
 use URI::Escape 'uri_unescape';
 use Plack::Request;
 
-use Object::Tiny::RW  qw/ app env self_url url_map _req /;
+use WebNano::FindController 'find_nested';
+use Object::Tiny::RW  qw/ app env self_url url_map _req path /;
 
 sub DEBUG { shift->app->DEBUG }
 
@@ -29,7 +30,8 @@ sub render {
 }
 
 sub local_dispatch {
-    my ( $self, @parts ) = @_;
+    my ( $self ) = @_;
+    my @parts = @{ $self->path };
     my $name = uri_unescape( shift @parts );
     $name = 'index' if !defined( $name ) || !length( $name );
     my $action;
@@ -41,8 +43,11 @@ sub local_dispatch {
             $action = $self->can( $name ) if grep { $_ eq $name } @$map;
         }
     }
-    my $method = $name . '_action';
-    $action = $self->can( $method ) if !$action;
+    $action = $self->can( $name . '_action' ) if !$action;
+    if( ! $action ){
+        my $method = uc( $self->env->{REQUEST_METHOD} );
+        $action = $self->can( $name . '_' . $method ) if $method eq 'GET' || $method eq 'POST';
+    }
     my $out;
     if( $action ){
         $out = $action->( $self, @parts );
@@ -51,12 +56,44 @@ sub local_dispatch {
     return $out;
 }
 
+
+sub _self_path{
+    my $class = shift;
+    my $path = $class;
+    $path =~ s/.*::Controller(?=(::|$))//;
+    $path =~ s{::}{/};
+    return $path . '/';
+}
+
+sub dispatch_to_class {
+    my ( $self, $to ) = @_;
+    $to =~ s/::|'//g if defined( $to );
+    return if !length( $to );
+    my $class = ref $self;
+    my $controller_class = find_nested( $class->_self_path . $to, $self->app->controller_search_path );
+    if( !$controller_class ){
+        warn qq{No subcontroller found in "$class" for "} . $class->_self_path . $to. qq{"\n} if $self->DEBUG;
+        return;
+    }
+    warn qq{Dispatching to "$controller_class"\n} if $self->DEBUG;
+    return $controller_class->handle(
+        path => $self->path,
+        app => $self->app,
+        self_url  => $self->{self_url} . $to. '/',
+        env => $self->env,
+    );
+}
+
 sub handle {
     my ( $class, %args ) = @_;
-    my $path = delete $args{path};
     my $self = $class->new( %args );
-    return $self->local_dispatch( @$path );
-};
+    my $out = $self->local_dispatch();
+    return $out if defined( $out ) || !$self->search_subcontrollers;
+    my $path_part = shift @{ $self->path };
+    return $self->dispatch_to_class( $path_part );
+}
+
+sub search_subcontrollers { 0 }
 
 1;
 
@@ -70,7 +107,7 @@ WebNano::Controller - WebNano Controller
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -80,6 +117,16 @@ to appropriate action method or to a next controller.
 The action method should return a string containing the HTML page, 
 a Plack::Response object or a code ref.
 
+If there is no suitable method in the current class and the method search_subcontrollers
+returns a true value then child controller classes
+are tried out.  If there is found one that matches the path part then it is
+instantiated with the current psgi env and it's handle method is called.
+
+In a path C</SomeDeepController/OtherController/LeaveController/method> all
+C<MyApp::Controoler>, C<MyApp::Controller::SomeDeepController> 
+and C<MyApp::Controller::SomeDeepController::OtherController> need to 
+override search_subcontrollers method to return 1.
+
 =head1 SYNOPSIS
 With Moose:
 
@@ -125,6 +172,13 @@ Plack::Reqest made from env
 
 =head2 template_search_path
 
+=head2 search_subcontrollers
+
+If search_subcontrollers returns true and there are no local actions
+then subcontrollers are searched.
+
+=head2 dispatch_to_class
+
 =head2 DEBUG
 
 By default returns the DEBUG flag from the application.  When this returns C<true> then
@@ -146,6 +200,8 @@ L<PSGI environment|http://search.cpan.org/~miyagawa/PSGI/PSGI.pod#The_Environmen
 
 =head2 self_url
 
+=head2 path
+
 =head1 AUTHOR
 
 Zbigniew Lukasiak <zby@cpan.org>
