@@ -3,7 +3,9 @@ use warnings;
 
 package MyApp::Controller;
 
-use base 'WebNano::DirController';
+use base 'WebNano::Controller';
+
+sub search_subcontrollers { 1 }
 
 sub new {
     my $class = shift;
@@ -34,5 +36,7 @@ sub streaming_action {
     }
 }
 
+sub postonly_POST { 'This is a method with _POST postfix' }
+
 1;
 
