@@ -3,6 +3,8 @@ use warnings;
 
 package MyApp::Controller::Deep;
 
-use base 'WebNano::DirController';
+use base 'WebNano::Controller';
+
+sub search_subcontrollers { 1 }
 
 1;
